@@ -140,6 +140,34 @@ sub editField
 }
 
 
+sub editBoolean
+{
+    my $self = shift;
+
+    my $model = $self->{'tableModel'};
+    my $id = $self->param('id');
+    my $field = $self->param('field');
+    my $value = 0;
+    if ($self->param('value')) {
+        $value = 1;
+    }
+
+    my $currentRow = $model->row($id);
+    my $element = $currentRow->elementByName($field);
+    $element->setValue($value);
+    $model->setTypedRow( $id, { $field => $element},
+                        force => 1,
+                        readOnly => 0);
+    $model->popMessage();
+    my $global = EBox::Global->getInstance();
+    # XXX Factor this class to be able to print 'application/json'
+    #     and 'text/html' headers. This way we could just return
+    #     a json object { changes_menu: true } and get it evaled
+    #     using prototype. That's the right way :)
+    if ($global->unsaved()) {
+        print '$("changes_menu").className = "changed"';
+    }
+}
 
 
 # Method to refresh the table by calling rows method
@@ -231,6 +259,9 @@ sub _process
         # from ClientRawBase instead of ClientBase
         $self->{template} = $model->Viewer();
         $self->refreshTable();
+    } elsif ($action eq 'editBoolean') {
+        delete $self->{template};
+        $self->editBoolean();
     }
 }
 
