@@ -31,8 +31,8 @@ use EBox::Exceptions::External;
 sub new # (error=?, msg=?, cgi=?)
 {
 	my $class = shift;
-	my $self = $class->SUPER::new('title' => __('System backups'),
-				      'template' => '/backup.mas',
+	my $self = $class->SUPER::new('title' => __('Backup'),
+				      'template' => '/backupTabs.mas',
 				      @_);
 	$self->{errorchain} = "EBox/Backup";
 	bless($self, $class);
@@ -92,9 +92,9 @@ sub optionalParameters
 
   if ($self->param('cancel')) {
     return ['.*'];
-  }   
+  }
 
-  return [];
+  return ['selected'];
 }
 
 
@@ -106,19 +106,19 @@ sub actuate
 
   if ($self->param('backup')) {
     $self->_backupAction();
-  } 
+  }
   elsif ($self->param('bugreport')) {
     $self->_bugreportAction();
-    } 
+    }
   elsif ($self->param('delete')) {
       $self->_deleteAction();
-    } 
+    }
   elsif ($self->param('download')) {
     $self->_downloadAction();
-  } 
+  }
   elsif ($self->param('restoreFromId')) {
     $self->_restoreFromIdAction();
-  } 
+  }
   elsif ($self->param('restoreFromFile')) {
     $self->_restoreFromFileAction();
   }
@@ -130,14 +130,14 @@ sub masonParameters
 {
   my ($self) = @_;
   my @params = ();
- 
+
   my $backup = EBox::Backup->new();
   push @params, (backups => $backup->listBackups());
 
   my $global = EBox::Global->getInstance();
   my $modulesChanged = grep { $global->modIsChanged($_) } @{ $global->modNames() };
   push @params, (modulesChanged => $modulesChanged);
-
+  push @params, (selected => 'local');
 
 
   return \@params;
@@ -168,7 +168,7 @@ sub  _backupAction
   $progressIndicator= $backup->prepareMakeBackup(description => $description, fullBackup => $fullBackup);
 
   $self->_showBackupProgress($progressIndicator);
-} 
+}
 
 
 
@@ -180,7 +180,7 @@ sub  _restoreFromFileAction
   # poor man decode html entity for '/'
   $filename =~ s{%2F}{/}g;
   $self->_restore($filename);
-} 
+}
 
 sub _restoreFromIdAction
 {
@@ -193,7 +193,7 @@ sub _restoreFromIdAction
   }
 
   $self->_restore(EBox::Config::conf ."/backups/$id.tar");
-}  
+}
 
 
 sub _restore
@@ -204,7 +204,7 @@ sub _restore
 
   my $backup = new EBox::Backup;
 
-  my $progressIndicator = 
+  my $progressIndicator =
     $backup->prepareRestoreBackup($filename, fullRestore => $fullRestore);
 
   $self->_showRestoreProgress($progressIndicator);
@@ -256,7 +256,7 @@ sub _showRestoreProgress
 		      currentItemCaption =>   __('Module') ,
 		      itemsLeftMessage   =>   __('modules left to restore'),
 		      endNote            =>   __('Restore successful'),
-		      reloadInterval     =>   2,
+		      reloadInterval     =>   4,
 );
 }
 
@@ -287,7 +287,7 @@ sub  _deleteAction
   }
   my $backup = EBox::Backup->new();
   $backup->deleteBackup($id);
-} 
+}
 
 sub  _bugreportAction
 {
@@ -297,6 +297,6 @@ sub  _bugreportAction
   $self->{errorchain} = "EBox/Bug";
   $self->{downfile} = $backup->makeBugReport();
   $self->{downfilename} = 'eboxbugreport.tar';
-} 
+}
 
 1;
