@@ -28,8 +28,8 @@ sub new # (cgi=?)
 	my $class = shift;
 	my $self = $class->SUPER::new(@_);
 	bless($self, $class);
-	$self->{errorchain} = "/Summary/Index";
-	$self->{redirect} = "/Summary/Index";
+	$self->{errorchain} = "/Dashboard/Index";
+	$self->{redirect} = "/Dashboard/Index";
 	return $self;
 }
 
@@ -47,9 +47,10 @@ sub _process
 
 	$self->_requireParam('module', __('module name'));
 	my $mod = $global->modInstance($self->param('module'));
-	$self->{chain} = "/Summary/Index";
+	$self->{chain} = "/Dashboard/Index";
 	$mod->restartService();
 	$self->{msg} = __('The module was restarted correctly.');
+        $self->cgi()->delete_all();
 }
 
 1;
