@@ -26,7 +26,7 @@ use warnings;
 
 use base 'EBox::CGI::ClientBase';
 
-use EBox::ServiceModule::Manager;
+use EBox::ServiceManager;
 use EBox::Global;
 use EBox::Gettext;
 
@@ -37,7 +37,7 @@ use EBox::Exceptions::Base;
 
 ## arguments:
 ## 	title [required]
-sub new 
+sub new
 {
     my $class = shift;
     my $self = $class->SUPER::new( @_);
@@ -54,21 +54,26 @@ sub _process
 
     $self->_requireParam('module');
     my $modName = $self->param('module');
-    my $manager = new EBox::ServiceModule::Manager();
+    my $manager = new EBox::ServiceManager();
     my $module = EBox::Global->modInstance($modName);
 
     $module->setConfigured(1);
     $module->enableService(1);
     $manager->updateModuleDigests($modName);
-    
+
     try {
         $module->enableActions();
     } otherwise {
         my ($excep) = @_;
         $module->setConfigured(undef);
         $module->enableService(undef);
-        #throw EBox::Exceptions::Internal($excep->as_string());
-        throw EBox::Exceptions::Internal("Failed to enable");
+        if ($excep->isa("EBox::Exceptions::External")) {
+            throw EBox::Exceptions::External("Failed to enable: " .
+                $excep->stringify());
+        } else {
+            throw EBox::Exceptions::Internal("Failed to enable: " .
+                $excep->stringify());
+        }
     };
 
     $manager->updateModuleDigests($modName);
