@@ -26,7 +26,7 @@ use warnings;
 
 use base 'EBox::CGI::ClientRawBase';
 
-use EBox::ServiceModule::Manager;
+use EBox::ServiceManager;
 use EBox::Global;
 use EBox::Gettext;
 
@@ -34,7 +34,7 @@ use EBox::Gettext;
 
 ## arguments:
 ## 	title [required]
-sub new 
+sub new
 {
     my $class = shift;
     my $self = $class->SUPER::new('template' => '/moduleStatusTable.mas', @_);
@@ -56,18 +56,18 @@ sub _process
         if (@params > 1) {
             $enabled = 1;
         }
-        $modules{$mod} = $enabled; 
+        $modules{$mod} = $enabled;
     }
 
 #     use Data::Dumper;
 #     EBox::debug(Dumper \%modules);
 
-    my $manager = new EBox::ServiceModule::Manager();
+    my $manager = new EBox::ServiceManager();
     $manager->enableServices(\%modules);
 
     my $modules = $manager->moduleStatus();
     my @params;
-    push @params, (modules => $modules, 
+    push @params, (modules => $modules,
                    hasChanged => EBox::Global->getInstance()->unsaved());
 
     $self->{params} = \@params;
