@@ -25,7 +25,7 @@ use warnings;
 
 use base 'EBox::CGI::ClientBase';
 
-use EBox::ServiceModule::Manager;
+use EBox::ServiceManager;
 use EBox::Global;
 use EBox::Gettext;
 
@@ -33,10 +33,10 @@ use EBox::Gettext;
 
 ## arguments:
 ## 	title [required]
-sub new 
+sub new
 {
     my $class = shift;
-    my $self = $class->SUPER::new( 'title' => __('Module status configuration'),
+    my $self = $class->SUPER::new( 'title' => __('Module Status Configuration'),
                                    'template' => '/moduleStatus.mas',
             @_);
 
@@ -50,7 +50,7 @@ sub _process
 {
     my ($self) = @_;
 
-    my $manager = new EBox::ServiceModule::Manager();
+    my $manager = new EBox::ServiceManager();
     my $modules = $manager->moduleStatus();
     my @params;
     push @params, (modules => $modules);
