@@ -72,6 +72,7 @@ sub _process
 
     my $composite = $self->{'composite'};
     my $directory = $self->param('directory');
+    $self->setMenuFolder($composite->menuFolder());
 
     if (defined $directory) {
         $composite->setDirectory($directory);
@@ -80,7 +81,7 @@ sub _process
         $composite->setDirectory('');
     }
 
-
+    $composite->setDomain();
     $self->{params} = $self->masonParameters();
 }
 
