@@ -33,6 +33,7 @@ use EBox::Exceptions::NotImplemented;
 use EBox::Exceptions::MissingArgument;
 use EBox::Event;
 use EBox::Gettext;
+use EBox::Model::ModelManager;
 
 # Constructor: new
 #
@@ -196,8 +197,11 @@ sub configurationSubModel
 
     my $manager = EBox::Model::ModelManager->instance();
     my $watchers = $manager->model('/events/ConfigureDispatcherDataTable');
-    my $row = $watchers->findValue('eventDispatcher' => $package);
-    return $row->subModel('configuration_model');
+    for my $id (@{$watchers->ids()}) {
+	my $row = $watchers->row($id);
+	next unless ($row->valueByName('eventDispatcher') eq $package);
+	return $row->subModel('configuration_model');
+    }
 }
 # Group: Protected method
 
