@@ -36,12 +36,14 @@ use EBox::Config;
 use EBox::Exceptions::Internal;
 use EBox::Gettext;
 use EBox::Model::ModelManager;
-use EBox::Types::Boolean;
 use EBox::Types::HasMany;
+use EBox::Types::Link;
 use EBox::Types::Text;
 use EBox::Types::Union;
 use EBox::Types::Union::Text;
 
+use Error qw(:try);
+
 # Constants:
 #
 #      WATCHERS_DIR - String directory where the Watchers lie
@@ -86,7 +88,7 @@ sub new
 
   }
 
-# Method: rows
+# Method: syncRows
 #
 #      This method is overridden since the showed data is managed
 #      differently.
@@ -94,41 +96,60 @@ sub new
 #      - The data is already available from the eBox installation
 #
 #      - The adding/removal of event watchers is done dynamically
-#      reading the directories where the event watchers lies
+#      reading the directories where the event watchers are placed
 #
 #
 # Overrides:
 #
-#        <EBox::Model::DataTable::rows>
+#        <EBox::Model::DataTable::syncRows>
 #
-sub rows
+sub syncRows
   {
 
-      my ($self, $filter, $page) = @_;
+      my ($self, $currentIds) = @_;
 
       # If the GConf module is readonly, return current rows
       if ( $self->{'gconfmodule'}->isReadOnly() ) {
-          return $self->SUPER::rows($filter, $page);
+          return undef;
       }
-
-      # Fetch the current event watchers from gconf
-      my $currentRows = $self->SUPER::rows();
-
+      my $modIsChanged = EBox::Global->getInstance()->modIsChanged('events');
 
       my %storedEventWatchers;
-      foreach my $currentRow (@{$currentRows}) {
-          $storedEventWatchers{$currentRow->valueByName('eventWatcher')} = 'true';
-      }
-
       my %currentEventWatchers;
       my $watchersRef = $self->_fetchWatchers();
       foreach my $watcherFetched (@{$watchersRef}) {
           $currentEventWatchers{$watcherFetched} = 'true';
       }
 
+      my $modified = undef;
+      # Removing old ones
+      foreach my $id (@{$currentIds}) {
+          my $row;
+          my $removed = 0;
+          try {
+              $row = $self->row($id);
+          } catch EBox::Exceptions::Base with {
+              $self->removeRow( $id );
+              $modified = 1;
+              $removed  = 1;
+          };
+          next if ($removed);
+          my $stored = $row->valueByName('eventWatcher');
+          $storedEventWatchers{$stored} = 'true';
+          if ( exists ( $currentEventWatchers{$stored} )) {
+              # Check its ability
+              my $able = $self->_checkWatcherAbility($stored);
+              $self->setTypedRow($id, undef, readOnly => not $able);
+          } else {
+              $self->removeRow( $id );
+          }
+          $modified = 1;
+      }
+
       # Adding new ones
       foreach my $watcher (keys ( %currentEventWatchers )) {
           next if ( exists ( $storedEventWatchers{$watcher} ));
+          eval "use $watcher";
           my %params = ('eventWatcher' => $watcher,
                          # The value is obtained dynamically
                          'description'  => undef,
@@ -136,28 +157,20 @@ sub rows
                          'enabled'      => 0,
                          'configuration_selected' => 'configuration_'
                                                     . $watcher->ConfigurationMethod(),
-                         'readOnly'     => $self->_checkWatcherAbility($watcher),
+                         'readOnly'     => not $self->_checkWatcherAbility($watcher),
                        );
           if ( $watcher->ConfigurationMethod() eq 'none' ) {
               $params{configuration_none} = '';
           }
           $self->addRow( %params );
+          $modified = 1;
       }
 
-      # Removing old ones
-      foreach my $row (@{$currentRows}) {
-          my $stored = $row->valueByName('eventWatcher');
-          if ( exists ( $currentEventWatchers{$stored} )) {
-              # Check its ability
-              my $able = $self->_checkWatcherAbility($stored);
-              $self->setTypedRow($row->{id}, undef, readOnly => ! $able);
-          } else {
-              $self->removeRow( $row->{id} );
-          }
+      if ($modified and not $modIsChanged) {
+          $self->{'gconfmodule'}->_saveConfig();
+        EBox::Global->getInstance()->modRestarted('events');
       }
-
-
-      return $self->SUPER::rows($filter, $page);
+      return $modified;
 
   }
 
@@ -199,14 +212,14 @@ sub updatedRowNotify
 # Method: pageTitle
 #
 #   Overrides:
-#       
+#
 #       <EBox::Model::Composite::headTitle>
 #
 # Returns:
 #
 #
 #   undef
-sub pageTitle 
+sub pageTitle
 {
     return undef;
 }
@@ -214,14 +227,14 @@ sub pageTitle
 # Method: headTitle
 #
 #   Overrides:
-#       
+#
 #       <EBox::Model::Composite::headTitle>
 #
 # Returns:
 #
 #
 #   undef
-sub headTitle 
+sub headTitle
 {
     return undef;
 }
@@ -235,7 +248,7 @@ sub headTitle
 #
 #       name        - <EBox::Types::Text>
 #       description - <EBox::Types::Text>
-#       enabled     - <EBox::Types::Boolean>
+#       configuration - <EBox::Types::Union>
 #
 #       You can only edit enabled field to activate or deactivate the
 #       event. The event name and description are read-only fields.
@@ -268,6 +281,11 @@ sub _table
                                 editable      => 0,
                                 subtypes      =>
                                 [
+                                 new EBox::Types::Link(
+                                                       fieldName               => 'configuration_link',
+                                                       volatile                => 1,
+                                                       acquirer                => \&acquireURL,
+                                                      ),
                                  new EBox::Types::HasMany(
                                                           fieldName            => 'configuration_model',
                                                           foreignModelAcquirer => \&acquireConfModel,
@@ -284,7 +302,7 @@ sub _table
       my $dataTable =
         {
          tableName           => 'ConfigureEventDataTable',
-         printableTableName  => __('Configure events'),
+         printableTableName  => __('Configure Events'),
          actions => {
                      editField  => '/ebox/Events/Controller/ConfigureEventDataTable',
                      changeView => '/ebox/Events/Controller/ConfigureEventDataTable',
@@ -386,18 +404,51 @@ sub acquireConfModel
 
       my ($row) = @_;
 
-      my $className = $row->{eventWatcher};
+      my $className = $row->valueByName('eventWatcher');
 
       eval "use $className";
       if ( $@ ) {
-          # Error loading class -> dispatcher to remove
-          throw EBox::Exceptions::Internal("Class $className does not compile: $@");
+          # Error loading class -> watcher to remove
+          # Return the fallback model
+          return 'Fallback';
       }
 
       return $className->ConfigureModel();
 
   }
 
+# Function: acquireURL
+#
+#      Callback function used to gather the URL that will fill the
+#      value for the link
+#
+# Parameters:
+#
+#      instancedType - <EBox::Types::Abstract> the cell which will contain
+#      the URL
+#
+# Returns:
+#
+#      String - the URL
+#
+sub acquireURL
+{
+
+    my ($instancedType) = @_;
+
+    my $className = $instancedType->row()->valueByName('eventWatcher');
+
+    eval "use $className";
+    if ( $@ ) {
+        # Error loading class -> dispatcher to remove
+        return;
+    }
+
+    return $className->ConfigureURL();
+
+}
+
+
 # Group: Private methods
 
 # Fetch the current watchers on the system
