@@ -23,6 +23,8 @@
 #    - spaceThreshold - Int the minimum disk free space before
 #    notifying the user of lack of space in a disk
 #
+use strict;
+use warnings;
 
 package EBox::Events::Model::Watcher::DiskFreeSpace;
 
@@ -120,4 +122,28 @@ sub _table
 
   }
 
+# Method: viewCustomizer
+#
+#   Overrides <EBox::Model::DataTable::viewCustomizer> to
+#   provide a custom HTML title with breadcrumbs
+#
+sub viewCustomizer
+{
+        my ($self) = @_;
+
+        my $custom =  $self->SUPER::viewCustomizer();
+        $custom->setHTMLTitle([
+                {
+                title => __('Events'),
+                link  => '/ebox/Events/Composite/GeneralComposite',
+                },
+                {
+                title => __('Free Disk Space Watcher'),
+                link  => ''
+                }
+        ]);
+
+        return $custom;
+}
+
 1;
