@@ -23,7 +23,7 @@ use base 'EBox::GConfHelper';
 use EBox::Gettext;
 use EBox::Exceptions::Internal;
 
-sub new 
+sub new
 {
 	my $class = shift;
 	my %opts = @_;
@@ -71,7 +71,7 @@ sub key # (key)
 
 
 # ! this also marks the module as changed
-sub backup 
+sub backup
 {
 	my $self = shift;
 	if ($self->isReadOnly) {
@@ -84,6 +84,16 @@ sub backup
 	$self->{mod}->_dump_to_file;
 
 	$global->modChange($self->{mod}->name);
+
+        # XXX I had placed this after the modChange mark bz otherway i get a
+        # infintie loop. It would be better untangle the problem and had it
+        # before the changed mark
+        if ($self->{mod}->isa('EBox::Model::ModelProvider')) {
+            $self->{mod}->modelsBackupFiles();
+        }
+
+
+
 }
 
 1;
