@@ -1,4 +1,5 @@
 # Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2009 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -25,6 +26,7 @@ use EBox::Exceptions::Command;
 use EBox::Exceptions::InvalidData;
 use EBox::Exceptions::DataNotFound;
 use EBox::Exceptions::Internal;
+use EBox::Exceptions::MissingArgument;
 use EBox::Exceptions::DataExists;
 use Error qw(:try);
 use EBox::Config;
@@ -46,6 +48,7 @@ use Digest::MD5;
 use constant {
     PRESAVE_SUBDIR  => EBox::Config::etc() . 'pre-save',
     POSTSAVE_SUBDIR => EBox::Config::etc() . 'post-save',
+    TIMESTAMP_KEY   => 'saved_timestamp',
 };
 
 
@@ -53,18 +56,18 @@ use constant {
 #for Singleton pattern
 sub _new_instance
 {
-        my $class = shift;
-        my $self = $class->SUPER::_create(name => 'global', @_);
-        bless($self, $class);
-        $self->{'mod_instances'} = {};
-        $self->{'mod_instances_hidden'} = {};
-        return $self;
+    my $class = shift;
+    my $self = $class->SUPER::_create(name => 'global', @_);
+    bless($self, $class);
+    $self->{'mod_instances'} = {};
+    $self->{'mod_instances_hidden'} = {};
+    return $self;
 }
 
 sub isReadOnly
 {
-        my $self = shift;
-        return $self->{ro};
+    my $self = shift;
+    return $self->{ro};
 }
 
 #Method: readModInfo
@@ -135,16 +138,38 @@ sub _writeModInfo
 #
 sub modExists # (module)
 {
-        my ($self, $name) = @_;
-        return defined($self->_className($name));
+    my ($self, $name) = @_;
+    return defined($self->_className($name));
 }
 
+# Method: modEnabled
 #
+#      Check if a module exists and it's enabled
+#
+# Parameters:
+#
+#       module -  module's name to check
+#
+# Returns:
+#
+#       boolean - True if the module is enabled, otherwise false
+#
+sub modEnabled # (module)
+{
+    my ($self, $name) = @_;
+
+    unless ($self->modExists($name)) {
+        return 0;
+    }
+    my $mod = $self->modInstance($name);
+    return $mod->isEnabled();
+}
+
 # Method: modIsChanged
 #
 #      Check if the module config has changed
 #
-#       Global module is considered always unchanged
+#      Global module is considered always unchanged
 #
 # Parameters:
 #
@@ -157,18 +182,17 @@ sub modExists # (module)
 
 sub modIsChanged # (module)
 {
-        my ($self, $name) = @_;
+    my ($self, $name) = @_;
 
-        defined($name) or return undef;
-        ($name ne 'global') or return undef;
+    defined($name) or return undef;
+    ($name ne 'global') or return undef;
 
-        $self->modExists($name) or return undef;
+    $self->modExists($name) or return undef;
 
-        my $info = readModInfo($name);
-        return $self->get_bool("modules/$name/changed");
+    my $info = readModInfo($name);
+    return $self->get_bool("modules/$name/changed");
 }
 
-#
 # Method: modChange
 #
 #       Set a module as changed
@@ -181,18 +205,18 @@ sub modIsChanged # (module)
 #
 sub modChange # (module)
 {
-        my ($self, $name) = @_;
-        defined($name) or return;
-        ($name ne 'global') or return;
+    my ($self, $name) = @_;
+    defined($name) or return;
+    ($name ne 'global') or return;
 
-        return if $self->modIsChanged($name);
+    return if $self->modIsChanged($name);
 
-        my $mod = $self->modInstance($name);
-        defined($mod) or throw EBox::Exceptions::Internal("Module $name does not exist");
+    my $mod = $self->modInstance($name);
+    defined($mod) or throw EBox::Exceptions::Internal("Module $name does not exist");
 
-        $mod->initChangedState();
+    $mod->initChangedState();
 
-        $self->set_bool("modules/$name/changed", 1);
+    $self->set_bool("modules/$name/changed", 1);
 }
 
 #
@@ -206,15 +230,14 @@ sub modChange # (module)
 #
 sub modRestarted # (module)
 {
-        my ($self, $name) = @_;
-        defined($name) or return;
-        ($name ne 'global') or return;
-        $self->modExists($name) or return;
+    my ($self, $name) = @_;
+    defined($name) or return;
+    ($name ne 'global') or return;
+    $self->modExists($name) or return;
 
-        $self->set_bool("modules/$name/changed", undef);
+    $self->set_bool("modules/$name/changed", undef);
 }
 
-#
 # Method: modNames
 #
 #       Return an array containing all module names
@@ -225,46 +248,45 @@ sub modRestarted # (module)
 #
 sub modNames
 {
-        my $self = shift;
-        my $log = EBox::logger();
-        my $global = EBox::Global->instance();
-        my @allmods = ();
-        foreach (('sysinfo', 'network', 'firewall')) {
-                if ($self->modExists($_)) {
-                        push(@allmods, $_);
-                }
+    my $self = shift;
+    my $log = EBox::logger();
+    my $global = EBox::Global->instance();
+    my @allmods = ();
+    foreach (('sysinfo', 'network', 'firewall')) {
+        if ($self->modExists($_)) {
+            push(@allmods, $_);
         }
-        my @files = glob(EBox::Config::share() . '/ebox/modules/*.yaml');
-        my @mods = map { basename($_) =~ m/(.*)\.yaml/ ; $1 } @files;
-        foreach my $mod (@mods) {
-                next unless ($self->modExists($mod));
-                next if (grep(/^$mod$/, @allmods));
-                my $class = $self->_className($mod);
-                if(defined($class)) {
-                        push(@allmods, $mod);
-                }
+    }
+    my @files = glob(EBox::Config::share() . '/ebox/modules/*.yaml');
+    my @mods = map { basename($_) =~ m/(.*)\.yaml/ ; $1 } @files;
+    foreach my $mod (@mods) {
+        next unless ($self->modExists($mod));
+        next if (grep(/^$mod$/, @allmods));
+        my $class = $self->_className($mod);
+        if(defined($class)) {
+            push(@allmods, $mod);
         }
-        return \@allmods;
+    }
+    return \@allmods;
 }
 
-#
 # Method: unsaved
 #
 #       Tell you if there is at least one unsaved module
 #
 # Returns:
 #
-#   	boolean - indicating if at least a module has unsaved changes
+#       boolean - indicating if at least a module has unsaved changes
 #
 sub unsaved
 {
-        my $self = shift;
-        my @names = @{$self->modNames()};
-        foreach (@names) {
-                $self->modIsChanged($_) or next;
-                return 1;
-        }
-        return undef;
+    my $self = shift;
+    my @names = @{$self->modNames()};
+    foreach (@names) {
+        $self->modIsChanged($_) or next;
+        return 1;
+    }
+    return undef;
 }
 
 
@@ -279,7 +301,6 @@ sub prepareRevokeAllModules
     return $self->_prepareActionScript('revokeAllModules', $totalTicks);
 }
 
-#
 # Method: revokeAllModules
 #
 #       Revoke the changes made in the configuration for all the modules
@@ -321,9 +342,26 @@ sub revokeAllModules
         throw EBox::Exceptions::Internal($errorText);
 }
 
+# Method: modifiedModules
+#
+#      Return the list of modified modules sorted by from parameter
+#
+# Parameters:
+#
+#      from - String the result is sorted depending on this parameter:
+#             'enable' - the sort is done by enableDepends attribute
+#             'save'   - the sort is done by depends attribute
+#
+# Returns:
+#
+#      array ref - containing the list of modified module names
+#
 sub modifiedModules
 {
-    my ($self) = @_;
+    my ($self, $from) = @_;
+
+    defined($from) or throw EBox::Exceptions::MissingArgument('from');
+
     my @names = @{$self->modNames};
     my @mods;
 
@@ -345,42 +383,34 @@ sub modifiedModules
         }
     }
 
-    my $sorted = sortModulesEnableModDepends(\@mods);
-    return $sorted;
+    @mods = map { __PACKAGE__->modInstance($_) } @mods;
+
+    my $sorted;
+    if ( $from eq 'enable' ) {
+        $sorted = sortModulesEnableModDepends(\@mods);
+    } else {
+        $sorted = __PACKAGE__->sortModulesByDependencies(\@mods, 'depends');
+    }
+
+    my @sorted = map { $_->name() } @{$sorted};
+
+    return \@sorted;
 }
 
 sub sortModulesEnableModDepends
 {
     my ($mods) = @_;
-
-    my @modules = @{$mods};
-
-    my %anyDependencyByModule = map {
-        my $modname = $_;
-        my $mod = EBox::Global->modInstance($modname);
-        my $deps = [];
-        if ($mod->can('enableModDepends')) {
-            $deps = $mod->enableModDepends();
-        }
-        my $anyDependency = any( @{ $deps } );
-        ($modname => $anyDependency);
-    } @modules;
-
-    @modules = sort {
-        my $aDependsB =  $anyDependencyByModule{$a} eq $b ? 1 : 0;
-        my $bDependsA =  $anyDependencyByModule{$b} eq $a ? 1 : 0;
-
-        $aDependsB <=> $bDependsA;
-    } @modules;
-
-    return \@modules;
+    return __PACKAGE__->sortModulesByDependencies(
+        $mods,
+        'enableModDepends'
+       );
 }
 
 sub prepareSaveAllModules
 {
     my ($self) = @_;
 
-    my $totalTicks = scalar @{$self->modifiedModules()}
+    my $totalTicks = scalar @{$self->modifiedModules('save')}
       + $self->_nScripts(PRESAVE_SUBDIR, POSTSAVE_SUBDIR);
 
     return $self->_prepareActionScript('saveAllModules', $totalTicks);
@@ -421,9 +451,9 @@ sub saveAllModules
         my $progress = $options{progress};
         if (not $progress) {
             $progress = EBox::ProgressIndicator::Dummy->create();
-        }
+       }
 
-        my @mods = @{$self->modifiedModules()};
+        my @mods = @{$self->modifiedModules('save')};
         my $modNames = join (' ', @mods);
 
         $self->_runExecFromDir(PRESAVE_SUBDIR, $progress, $modNames);
@@ -474,6 +504,8 @@ sub saveAllModules
         }
         if ($failed eq "") {
             $self->_runExecFromDir(POSTSAVE_SUBDIR, $progress, $modNames);
+            # Store a timestamp with the time of the ending
+            $self->st_set_int(TIMESTAMP_KEY, time());
             $progress->setAsFinished();
             return;
         }
@@ -485,7 +517,6 @@ sub saveAllModules
         throw EBox::Exceptions::Internal($errorText);
 }
 
-#
 # Method: restartAllModules
 #
 #       Force a restart for all the modules
@@ -519,7 +550,6 @@ sub restartAllModules
                 "being restarted, their state is unknown: $failed");
 }
 
-#
 # Method: stopAllModules
 #
 #       Stops all the modules
@@ -554,7 +584,6 @@ sub stopAllModules
                 "stopping, their state is unknown: $failed");
 }
 
-#
 # Method: getInstance
 #
 #       Return an instance of global class
@@ -569,22 +598,22 @@ sub stopAllModules
 #
 sub getInstance # (read_only?)
 {
-        my $tmp = shift;
-        if (!$tmp or ($tmp ne 'EBox::Global')) {
-                throw EBox::Exceptions::Internal("Incorrect call to ".
+    my $tmp = shift;
+    if (!$tmp or ($tmp ne 'EBox::Global')) {
+        throw EBox::Exceptions::Internal("Incorrect call to ".
                 "EBox::Global->getInstance(), maybe it was called as an static".
                 " function instead of a class method?");
-        }
-        my $ro = shift;
-        my $global = EBox::Global->instance();
-        if ($global->isReadOnly xor $ro) {
-                $global->{ro} = $ro;
-                # swap instance groups
-                my $bak = $global->{mod_instances};
-                $global->{mod_instances} = $global->{mod_instances_hidden};
-                $global->{mod_instances_hidden} = $bak;
-        }
-        return $global;
+    }
+    my $ro = shift;
+    my $global = EBox::Global->instance();
+    if ($global->isReadOnly xor $ro) {
+        $global->{ro} = $ro;
+        # swap instance groups
+        my $bak = $global->{mod_instances};
+        $global->{mod_instances} = $global->{mod_instances_hidden};
+        $global->{mod_instances_hidden} = $bak;
+    }
+    return $global;
 }
 
 #
@@ -598,18 +627,17 @@ sub getInstance # (read_only?)
 #
 sub modInstances
 {
-        my $self = EBox::Global->instance();
-        my @names = @{$self->modNames};
-        my @array = ();
+    my $self = EBox::Global->instance();
+    my @names = @{$self->modNames};
+    my @array = ();
 
-        foreach my $name (@names) {
-                my $mod = $self->modInstance($name);
-                push(@array, $mod);
-        }
-        return \@array;
+    foreach my $name (@names) {
+        my $mod = $self->modInstance($name);
+        push(@array, $mod);
+    }
+    return \@array;
 }
 
-#
 # Method: modInstancesOfType
 #
 #       Return an array ref with an instance of every module that extends
@@ -626,23 +654,22 @@ sub modInstances
 #
 sub modInstancesOfType # (classname)
 {
-        shift;
-        my $classname = shift;
-        my $self = EBox::Global->instance();
-        my @names = @{$self->modNames};
-        my @array = ();
+    shift;
+    my $classname = shift;
+    my $self = EBox::Global->instance();
+    my @names = @{$self->modNames};
+    my @array = ();
 
-        foreach my $name (@names) {
-                my $mod = $self->modInstance($name);
-                if ($mod->isa($classname)) {
-                        push(@array, $mod);
-                }
+    foreach my $name (@names) {
+        my $mod = $self->modInstance($name);
+        if ($mod->isa($classname)) {
+            push(@array, $mod);
         }
-        return \@array;
+    }
+    return \@array;
 }
 
 
-#
 # Method: modInstance
 #
 #       Build an instance of a module. Can be called as a class method or as an
@@ -681,7 +708,7 @@ sub modInstance # (module)
         $global = $self;
     } else {
         throw EBox::Exceptions::Internal("Incorrect call to ".
-                                             "EBox::Global modInstance(), the first parameter is not a class".
+                                         "EBox::Global modInstance(), the first parameter is not a class".
                                          " nor an instance.");
     }
 
@@ -719,7 +746,6 @@ sub modInstance # (module)
 }
 
 
-#
 # Method: logger
 #
 #       Initialise Log4perl if necessary, returns the logger for the i
@@ -740,15 +766,15 @@ sub modInstance # (module)
 #       undef
 sub logger # (caller?)
 {
-        shift;
-        EBox::deprecated();
-        return EBox::logger(shift);
+    shift;
+    EBox::deprecated();
+    return EBox::logger(shift);
 }
 
 # Method: modDepends
 #
 #       Return an array ref with the names of the modules that the requested
-#       module deed on
+#       module depends on
 #
 #   Parameters:
 #
@@ -760,18 +786,13 @@ sub logger # (caller?)
 #       array ref - holding the names of the modules that the requested module
 sub modDepends # (module)
 {
-        my ($self, $name) = @_;
-        $self->modExists($name) or return undef;
-        my $info = readModInfo($name);
-        my @list = map {s/^\s+//; $_} @{$info->{'depends'}};
-        if (@list) {
-                return \@list;
-        } else {
-                return [];
-        }
+    my ($self, $name) = @_;
+
+    $self->modExists($name) or return undef;
+    my $mod = $self->modInstance($name);
+    return $mod->depends();
 }
 
-#
 # Method: modRevDepends
 #
 #       Return an array ref with the names of the modules which depend on a given
@@ -789,55 +810,154 @@ sub modDepends # (module)
 #
 sub modRevDepends # (module)
 {
-        my ($self, $name) = @_;
-        $self->modExists($name) or return undef;
-        my @revdeps = ();
-        my @mods = @{$self->modNames};
-        foreach my $mod (@mods) {
-                my @deps = @{$self->modDepends($mod)};
-                foreach my $dep (@deps) {
-                        defined($dep) or next;
-                        if ($name eq $dep) {
-                                push(@revdeps, $mod);
-                                last;
-                        }
-                }
+    my ($self, $name) = @_;
+    $self->modExists($name) or return undef;
+    my @revdeps = ();
+    my @mods = @{$self->modNames};
+    foreach my $mod (@mods) {
+        my @deps = @{$self->modDepends($mod)};
+        foreach my $dep (@deps) {
+            defined($dep) or next;
+            if ($name eq $dep) {
+                push(@revdeps, $mod);
+                last;
+            }
         }
-        return \@revdeps;
+    }
+    return \@revdeps;
 }
 
+
+# Name: sortModulesByDependencies
 #
+#  Sort a list of modules objects by its dependencies. The dependencies are get
+# using a method that returns the names of the dependencies of each module. 
+#
+#  Parameters:
+#        modules_r          - reference to list of modules
+#        dependenciesMethod - name of the method called in each module
+#                             to get its dependencies
+sub sortModulesByDependencies
+{
+    my ($package, $modules_r, $dependenciesMethod) = @_;
+
+    my @modules = @{ $modules_r };
+    my %availableModulesAndDependencies = map {
+        $_->name() => undef;
+    } @modules;
+
+    my $i =0;
+    while ($i < @modules) {
+        my $mod = $modules[$i];
+        my $modName = $mod->name();
+        my @depends = ();
+        if (defined $availableModulesAndDependencies{$modName}) {
+            @depends = @{ $availableModulesAndDependencies{$modName} }
+        } elsif ($mod->can($dependenciesMethod)) {
+            @depends  = @{ $mod->$dependenciesMethod() };
+            @depends = grep {
+                exists $availableModulesAndDependencies{$_}
+            } @depends;
+            $availableModulesAndDependencies{$modName} = \@depends;
+        }
+
+        my $depOk = 1;
+
+        foreach my $dependency (@depends) {
+            my $depFound = 0;
+            foreach my $j (0 .. $i) {
+                if ($i == $j) {
+                    # for $i ==0 case
+                    last;
+                } elsif ($modules[$j]->name() eq $dependency) {
+                    $depFound = 1;
+                    last;
+                }
+            }
+
+            if (not $depFound) {
+                $depOk = 0;
+                last;
+            }
+        }
+
+        if ($depOk) {
+            $i += 1;
+        } else {
+            my $unreadyMod = splice @modules, $i, 1;
+            push @modules, $unreadyMod;
+        }
+
+    }
+
+    return \@modules;
+}
+
+# Method: lastModificationTime
+#
+#      Return the latest modification time, this is the latest of
+#      these events:
+#
+#      - After finishing saving changes using <saveAllModules> call
+#      - After a modification in LDAP in users module is present and at
+#      least configured
+#
+# Returns:
+#
+#      Int - the lastModificationTime
+#
+sub lastModificationTime
+{
+    my ($self) = @_;
+
+    my $lastStamp = $self->st_get_int(TIMESTAMP_KEY);
+    $lastStamp = 0 unless defined($lastStamp);
+    if ( $self->modExists('users') ) {
+        my $usersMod = $self->modInstance('users');
+        if ( $usersMod->configured() ) {
+            my ($sec, $min, $hour, $mday, $mon, $year) = localtime($lastStamp);
+            my $lastStampStr = sprintf('%04d%02d%02d%02d%02d%02dZ',
+                                       ($year + 1900, $mon + 1, $mday, $hour,
+                                        $min, $sec));
+            my $ldapStamp = $usersMod->ldap()->lastModificationTime($lastStampStr);
+            if ( $ldapStamp > $lastStamp ) {
+                $lastStamp = $ldapStamp;
+            }
+        }
+    }
+    return $lastStamp;
+
+}
+
 # Method: setLocale
 #
 #       *deprecated*
 #
 sub setLocale # (locale)
 {
-        shift;
-        EBox::deprecated();
-        EBox::setLocale(shift);
+    shift;
+    EBox::deprecated();
+    EBox::setLocale(shift);
 }
 
-#
-# Method: setLocale
+# Method: locale
 #
 #       *deprecated*
 #
 sub locale
 {
-        EBox::deprecated();
-        return EBox::locale();
+    EBox::deprecated();
+    return EBox::locale();
 }
 
-#
-# Method: setLocale
+# Method: init
 #
 #       *deprecated*
 #
 sub init
 {
-        EBox::deprecated();
-        EBox::init();
+    EBox::deprecated();
+    EBox::init();
 }
 
 # Method: _runExecFromDir
@@ -906,7 +1026,6 @@ sub _runExecFromDir
             };
         }
     }
-
 }
 
 # Method: _nScripts
