@@ -1,4 +1,5 @@
 # Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2009 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -54,48 +55,83 @@ sub _create
     my $self = $class->SUPER::_create(
                                       name => 'logs',
                                       domain => 'ebox',
-                                      printableName => __('Logs'),
+                                      printableName => __n('Logs'),
                                      );
 
     bless($self, $class);
     return $self;
 }
 
-
-# Method: actions
+# Method: depends
 #
-#       Override EBox::Module::Service::actions
+#       Override EBox::Module::Base::depends
 #
-sub actions
+sub depends
 {
-    return [
-        {
-                'action' => __('Create logs database'),
-                'reason' => __('eBox store its logs in the database'),
-                'module' => 'logs'
-        }
-    ];
-}
-
-
-# Method: enableActions
-#
-#       Override EBox::Module::Service::enableActions
-#
-sub enableActions
-{
-    EBox::Sudo::root(EBox::Config::share() . '/ebox/ebox-logs-enable');
+    my $mods = EBox::Global->modInstancesOfType('EBox::LogObserver');
+    my @names = map ($_->{name}, @$mods);
+    return \@names;
 }
 
 sub _daemons
 {
     return [
         {
-            'name' => LOG_DAEMON
+            'name' => LOG_DAEMON,
+            'precondition' => \&_loggerdPrecondition,
         }
     ];
 }
 
+
+#  Method: _loggerdPrecondition
+#
+#   loggerd daemon precondition, checks that a least one logger domain is
+#   enabled
+sub _loggerdPrecondition
+{
+    my ($self) = @_;
+    my $enabled = $self->allEnabledLogHelpers();
+    return @{ $enabled } > 0;
+}
+
+
+
+# Method: enableService
+#
+#   Used to enable a service. Overriddien to notify all LogObserver of the
+#   changes. 
+#
+# Parameters:
+#
+#   boolean - true to enable, false to disable
+#
+#  Overriddes:
+#  <EBox::Module::service::enableService >
+sub enableService
+{
+    my ($self, $status) = @_;
+    defined $status or
+        $status = 0;
+
+    return unless ($self->isEnabled() xor $status);
+
+    $self->SUPER::enableService($status);
+    $self->_notifyLogEnable();
+}
+
+
+
+sub _notifyLogEnable
+{
+    my ($self, $status) = @_;
+    my $modules = $self->getLogsModules();
+    foreach my $module (@{ $modules }) {
+        $module->enableLog($status);
+    }
+    
+}
+
 # Method: isRunning
 #
 # Overrides:
@@ -157,38 +193,6 @@ sub compositeClasses
            ];
 }
 
-
-
-
-
-# Method: allLogDomains
-#
-#       This function fetchs all the log domains available throughout
-#       ebox. *(Deprecated)*
-#
-# Returns:
-#
-#       An array ref containing  hash references holding:
-#
-#               logdomain - log domain name
-#               text - log domain name i18n
-#
-sub allLogDomains
-{
-    my ($self) = @_;
-
-    my $global = EBox::Global->getInstance();
-
-    my @domains;
-    my @mods = @{$global->modInstancesOfType('EBox::LogObserver')};
-    foreach my $mod (@mods) {
-        my $dm = $mod->logDomain();
-        next unless defined($dm);
-        push @domains, $dm;
-    }
-    return \@domains;
-}
-
 # Method: allEnabledLogHelpers
 #
 #       This function fetchs all the classes implemeting the interface
@@ -199,7 +203,7 @@ sub allLogDomains
 #
 # Returns:
 #
-#       Array ref of objects <EBox::LogObserver>
+#       Array ref of objects <EBox::LogHelper>
 #
 sub allEnabledLogHelpers
 {
@@ -217,9 +221,12 @@ sub allEnabledLogHelpers
 
     my @enabledObjects;
     my @mods = @{$global->modInstancesOfType('EBox::LogObserver')};
-    foreach my $mod  (@mods) {
-        if ( $enabledLogs->{$mod->name } ) {
-            push (@enabledObjects, $mod->logHelper());
+    foreach my $mod (@mods) {
+        if ($global->modEnabled($mod->name) and $enabledLogs->{$mod->name}) {
+            my $logHelper = $mod->logHelper();
+            defined $logHelper or
+                next;
+            push (@enabledObjects, $logHelper);
         }
     }
 
@@ -258,7 +265,7 @@ sub getLogsModules
 {
     my $global = EBox::Global->getInstance();
 
-    return $global->modInstancesOfType('EBox::LogObserver');
+    return [grep { $_->configured() } @{$global->modInstancesOfType('EBox::LogObserver')}];
 }
 
 sub getAllTables
@@ -297,6 +304,11 @@ sub getTableInfo
     my ($self, $index) = @_;
 
     my $tables = $self->getAllTables();
+    unless (exists $tables->{$index}) {
+        $self->{tables} = undef; # Delete cache
+        $tables = $self->getAllTables(); # Ask again
+    }
+
     return $tables->{$index};
 }
 
@@ -313,7 +325,7 @@ sub getModTableInfos
     }
     elsif (ref $ti eq 'HASH') {
         EBox::warn('tableInfo() in ' . $mod->name .
-                   'must return a reference to a list of hashes not the hash itself');
+                   ' must return a reference to a list of hashes not the hash itself');
         @tableInfos = ( $ti );
     }
     else {
@@ -398,9 +410,6 @@ sub _checkValidDate # (date)
 #
 #       page - Int the page to search for results
 #
-#       timecol - String the table field which contains the timestamp
-#       value (time and date field)
-#
 #       filters - hash ref a list of filters indexed by name which
 #       contains the value of the given filter (normally a
 #       string). Passing *undef* no filters are applied
@@ -515,6 +524,58 @@ sub totalRecords
     return $tcount;
 }
 
+# Method: consolidatedLogForDay
+#
+# Parameters:
+#     table - consolidated table. The suffix '_daily' is added automaticallu
+#     date  - date in format yyyy-mm-dd
+#
+#  Returns: 
+#      array reference. Each row will be a hash reference with
+#      column/values as key/values. Remember that it will be always a 'date'
+#      field. 
+#      If there is not data it will return a empty array
+sub consolidatedLogForDay
+{
+    my ($self, $table, $date) = @_;
+    $date or
+        throw EBox::Exceptions::MissingArgument('date');
+    $table or
+        throw EBox::Exceptions::MissingArgument('table');
+    
+    # put the standard 00:00:00  hour
+    ($date) = split '\s', $date;
+    $date .= ' 00:00:00';
+
+
+    $table = $table . '_daily';
+
+    my $dbengine = EBox::DBEngineFactory::DBEngine();
+
+    my $sql = "SELECT * FROM $table WHERE date='$date'";
+    
+    my @results = @{  $dbengine->query($sql) };
+    return \@results;
+}
+
+# Method: yesterdayDate
+#
+#  Returns:
+#    the yesterday date in string format so it can used in SQL queries and 
+#    i nthe consolidatedLogForDay method
+sub yesterdayDate
+{
+    my ($self) = @_;
+    my $yesterdayTs = time()  - 86400; # 86400 seconds in a day
+    my  ($sec,$min,$hour,$mday,$mon,$year) = localtime($yesterdayTs);
+    $year += 1900;
+    $mon  +=1;
+
+    return "$year-$mon-$mday 00:00:00";
+}
+
+
+
 sub _addRegExp
 {
     my ($self, $field, $regexp) = @_;
@@ -623,7 +684,7 @@ sub menu
     my ($self, $root) = @_;
     my $folder = new EBox::Menu::Folder('name' => 'Logs',
                                         'text' => $self->printableName(),
-                                        'separator' => __('Core'),
+                                        'separator' => 'Core',
                                         'order' => 80);
 
     $folder->add(new EBox::Menu::Item('url' => 'Logs/View/SelectLog',
@@ -658,7 +719,6 @@ sub tableInfo
             'titles' => $titles,
             'order' => \@order,
             'tablename' => 'admin',
-            'timecol' => 'timestamp',
             'filter' => ['source', 'module']
            };
 }
@@ -683,8 +743,8 @@ sub _saveEnabledLogsModules
     my $enabledLogs = $self->model('ConfigureLogTable')->enabledLogs();
 
     unless (-d ENABLED_LOG_CONF_DIR) {
-                mkdir (ENABLED_LOG_CONF_DIR);
-            }
+        mkdir (ENABLED_LOG_CONF_DIR);
+    }
 
     # Create a string of domains separated by comas
     my $enabledLogsString = join (',', keys %{$enabledLogs});
@@ -692,7 +752,7 @@ sub _saveEnabledLogsModules
     my $file;
     unless (open($file, '>' . ENABLED_LOG_CONF_FILE)) {
         throw EBox::Exceptions::Internal(
-                                         'Cannot open ' . ENABLED_LOG_CONF_FILE);
+                'Cannot open ' . ENABLED_LOG_CONF_FILE);
     }
 
     print $file "$enabledLogsString";
@@ -703,7 +763,7 @@ sub _saveEnabledLogsModules
 #
 #       (Private)
 #
-#       This function restores the  enabled logs saved in a file by
+#       This function restores the enabled logs saved in a file by
 #       <EBox::Logs::_saveEnabledLogsModules>
 #       We have to do this beacuse the logger daemon will request this
 #       configuration as root user.
@@ -786,7 +846,7 @@ sub forcePurge
 
   foreach my $tableInfo ( @tables ) {
     my $table = $tableInfo->{tablename};
-    my $timeCol = $tableInfo->{timecol};
+    my $timeCol = 'timestamp';
     $self->_purgeTable($table, $timeCol, $thresholdDate);
   }
 }
@@ -833,7 +893,7 @@ sub purge
 
       foreach my $table (@logTables) {
           my $dbTable = $table->{tablename};
-          my $timeCol = $table->{timecol};
+          my $timeCol = 'timestamp';
 
           $self->_purgeTable($dbTable, $timeCol, $threshold);
       }
@@ -842,9 +902,6 @@ sub purge
   }
 }
 
-# Transform an hour into a localtime
-
-
 
 # Transform an hour into a localtime
 sub _thresholdDate
@@ -867,5 +924,4 @@ sub _purgeTable #(tablename, timecolumn, thresholdDate)
   $dbengine->query($sqlStatement);
 }
 
-
 1;
