@@ -15,7 +15,7 @@
 
 # Class: ModelManager
 #
-#   This class is used to coordinate all the available models 
+#   This class is used to coordinate all the available models
 #   along eBox. It allows us to do things like specifiying relations
 #   amongst different models.
 #
@@ -31,6 +31,8 @@ use EBox::Gettext;
 use EBox::Global;
 use EBox::Exceptions::Internal;
 use EBox::Exceptions::DataNotFound;
+use EBox::Exceptions::DataInUse;
+use EBox::Model::CompositeManager;
 use Error qw(:try);
 
 # Constant
@@ -46,7 +48,7 @@ sub _new
 
     my $self = {};
 
-    $self->{'notifyActions'} = {}; 
+    $self->{'notifyActions'} = {};
     bless($self, $class);
 
     $self->{'version'} = $self->_version();
@@ -118,11 +120,11 @@ sub model
 
 
     unless (  $path ) {
-        throw EBox::Exceptions::MissingArgument('path');
+        throw EBox::Exceptions::MissingArgument(q{model's path});
     }
 
     my ($moduleName, $modelName, @parameters) = grep { $_ ne '' } split ( '/', $path);
-    
+
     if (not $moduleName) {
         throw EBox::Exceptions::Internal('Invalid path');
     }
@@ -157,7 +159,7 @@ sub model
             if ((@parameters and $parameters[0] eq '*') or $nModels > 1) {
                 return $self->{'models'}->{$moduleName}->{$modelName};
             } else {
-                return 
+                return
                     $self->{'models'}->{$moduleName}->{$modelName}->[0];
             }
         }
@@ -253,29 +255,29 @@ sub removeModel
 }
 
 
-# Method: modelsUsingId 
+# Method: modelsUsingId
 #
 #   Given a row id of a model, it returns the models which
 #   are currently referencing it
 #
-# Parameters: 
+# Parameters:
 #
 #   (POSITIONAL)
 #
-#   model - model string 
+#   model - model string
 #   rowId - string containing the row's id
 #
 # Returns:
 #
-#   
+#
 #
 # Exceptions:
 #
 # <EBox::Exceptions::DataNotFound> if the model does not exist
-sub modelsUsingId 
+sub modelsUsingId
 {
     my ($self, $modelName, $rowId) =  @_;
-    
+
     my $model = $self->model($modelName);
     unless (defined($model)) {
         throw EBox::Exceptions::DataNotFound(
@@ -293,7 +295,7 @@ sub modelsUsingId
 
         for my $fieldName (@{$modelDepHash->{$modelDepName}}) {
             if (defined($modelDep->findValue($fieldName => $rowId))) {
-                $models{$modelDepName} = 
+                $models{$modelDepName} =
                     $modelDep->table()->{'printableTableName'};
             }
         }
@@ -315,24 +317,24 @@ sub modelsUsingId
     return \%models;
 }
 
-# Method: modelActionTaken 
+# Method: modelActionTaken
 #
 #	This method is used to let models know when other model has
-#	taken an action. 
+#	taken an action.
 #
 #	It will automatically call the model in which descrption they
 #	request to be warned about the current action and model.
-#	
 #
-# Parameters: 
+#
+# Parameters:
 #
 #   (POSITIONAL)
 #
-#   model - model name where the action took place 
-#   action - string represting the action: 
+#   model - <EBox::Model::DataTable> model name where the action took place
+#   action - string represting the action:
 #   	     [ add, del, edit, moveUp, moveDown ]
 #
-#   row  - row modified 
+#   row  - <EBox::Model::Row> row modified
 #
 # Returns:
 #
@@ -347,9 +349,9 @@ sub modelActionTaken
 {
     my ($self, $model, $action, $row) = @_;
 
-    throw EBox::Exceptions::MissingArgument("model") unless (defined($model));
-    throw EBox::Exceptions::MissingArgument("action") unless (defined($action));
-    throw EBox::Exceptions::MissingArgument("row") unless (defined($row));
+    throw EBox::Exceptions::MissingArgument('model') unless (defined($model));
+    throw EBox::Exceptions::MissingArgument('action') unless (defined($action));
+    throw EBox::Exceptions::MissingArgument('row') unless (defined($row));
 
     # if ( defined $row->{'id'} ) {
     #    EBox::debug("$model has taken action '$action' on row $row->{'id'}");
@@ -374,15 +376,15 @@ sub modelActionTaken
 
 }
 
-# Method: removeRowsUsingId 
+# Method: removeRowsUsingId
 #
-#   Given a row id of a model, remove rows from models referencing it 
+#   Given a row id of a model, remove rows from models referencing it
 #
-# Parameters: 
+# Parameters:
 #
 #   (POSITIONAL)
 #
-#   model - model object 
+#   model - model object
 #   rowId - string containing the row's id
 #
 # Returns:
@@ -393,7 +395,7 @@ sub modelActionTaken
 # Exceptions:
 #
 # <EBox::Exceptions::DataNotFound> if the model does not exist
-sub removeRowsUsingId 
+sub removeRowsUsingId
 {
     my ($self, $modelName, $rowId) =  @_;
 
@@ -415,11 +417,11 @@ sub removeRowsUsingId
         my $deletedNum = 0;
         for my $fieldName (@{$modelDepHash->{$modelDepName}}) {
             my %rowsDeleted;
-            for my $row (@{$modelDep->findAllValue($fieldName => $rowId)}) {
-                next if (exists $rowsDeleted{$row->{'id'}});
-                $modelDep->removeRow($row->{'id'}, 1);
+            for my $id (@{$modelDep->findAllValue($fieldName => $rowId)}) {
+                next if (exists $rowsDeleted{$id});
+                $modelDep->removeRow($id, 1);
                 $deletedNum++;
-                $rowsDeleted{$row->{'id'}} = 1;
+                $rowsDeleted{$id} = 1;
             }
         }
         if ( $deletedNum > 0 ) {
@@ -574,8 +576,21 @@ sub _setRelationship
     my ($self) = @_;
 
     # Set parent models given by hasMany relationships
+
+    my $compositeManager = EBox::Model::CompositeManager->Instance();
+
     for my $childName (keys %{$self->{'childOf'}}) {
-        $self->model($childName)->setParent($self->{'childOf'}->{$childName});
+        my $parent       = $self->{'childOf'}->{$childName}->{'parent'};
+        my $childIsComposite = $self->{'childOf'}->{$childName}->{'childIsComposite'};
+
+        my $child;
+        if ($childIsComposite) {
+            $child = $compositeManager->composite($childName);
+        } else {
+            $child = $self->model($childName);
+        }
+
+        $child->setParent($parent);
     }
 
 
@@ -597,23 +612,17 @@ sub _setUpModelsFromProvider
 {
     my ($self, $provider) = @_;
 
-    try {
-        for my $model (@{$provider->models()}) {
-	    my $moduleName = $provider->name();
-	    my $modelName = $model->tableName();
-	    $modelName or 
-		throw EBox::Exceptions::Internal("Invalid model name $modelName");
+    for my $model (@{$provider->models()}) {
+        my $moduleName = $provider->name();
+        my $modelName = $model->tableName();
+        $modelName or
+            throw EBox::Exceptions::Internal("Invalid model name $modelName");
 
             push ( @{$self->{'models'}->{$moduleName}->{$modelName}}, $model);
         }
         for my $model (@{$provider->reloadModelsOnChange()}) {
             push ( @{$self->{'reloadActions'}->{$model}}, $provider->name());
         }
-    } otherwise {
-        my ($exc) = @_;
-        EBox::warn('Skipping ' . $provider->printableName() . ' to fetch model');
-        EBox::warn("Error: $exc");
-    };
 
     # Set up dependencies. Fetch all select types and check if
     # they depend on other model.
@@ -640,15 +649,22 @@ sub _setUpModelsFromProvider
             }
             for my $type (@{$dependentTypes->{'hasMany'}}) {
                 my $foreignModel;
+                my $isComposite;
                 try {
                     $foreignModel = $type->foreignModel();
+                    $isComposite  = $type->foreignModelIsComposite();
                 } otherwise {
                     my ($exc) = @_;
                     EBox::warn("Skipping " . $type->fieldName() . " to fetch model");
                     EBox::warn("Error: $exc");
                 };
                 next unless (defined($foreignModel) and $foreignModel ne '');
-                $self->{'childOf'}->{$foreignModel} = $model;
+
+
+                $self->{'childOf'}->{$foreignModel} = {
+                                                       parent => $model,
+                                                       childIsComposite => $isComposite,
+                                                      };
             }
 
         }
@@ -686,7 +702,7 @@ sub _setUpModelsFromProvider
 sub _modelsWithHasOneRelation
 {
     my ($self, $modelName) = @_;
-    
+
     return {} unless (exists($self->{'hasOneReverse'}->{$modelName}));
 
     return $self->{'hasOneReverse'}->{$modelName};
@@ -706,9 +722,9 @@ sub _modelsWithHasOneRelation
 # Parameters:
 #
 #   (POSITIONAL)
-#   
+#
 #   tableDescription - ref containing the table description
-#   
+#
 # Return:
 #
 #   Array ref containing the types
@@ -719,7 +735,7 @@ sub _fetchDependentTypes
 
     my @selectTypes;
     my @hasManyTypes;
-    foreach my $type (@{$tableDescription}) { 
+    foreach my $type (@{$tableDescription}) {
         if ($type->type() eq 'union') {
             for my $subtype (@{$type->subtypes()}) {
                  if ($subtype->type() eq 'select') {
@@ -735,7 +751,7 @@ sub _fetchDependentTypes
             push (@hasManyTypes, $type);
         }
     }
-    
+
     return { 'select' => \@selectTypes,
              'hasMany' => \@hasManyTypes };
 }
@@ -751,9 +767,9 @@ sub _fetchDependentTypes
 # Parameters:
 #
 #   (POSITIONAL)
-#   
-#   model - model's name 
-#   
+#
+#   model - model's name
+#
 # Return:
 #
 #  hash refs containing pairs of:
@@ -765,7 +781,7 @@ sub _oneToOneDependencies
     my ($self, $model) = @_;
 
     unless (exists $self->{'hasOneReverse'}->{$model}) {
-        return {};    
+        return {};
     }
 
     return $self->{'hasOneReverse'}->{$model};
@@ -874,7 +890,7 @@ sub _chooseModelUsingParameters
 # 	(PRIVATE)
 #
 #   Mark the model manager as changed. This is done when a change is
-#   done in the models to allow interprocess coherency. 
+#   done in the models to allow interprocess coherency.
 #
 #
 sub _hasChanged
