@@ -29,18 +29,18 @@ use EBox::Model::ModelManager;
 use constant TYPE => 'model';
 use constant DEFAULT_SEPARATOR => '/';
 
-# Method: models 
-# 
+# Method: models
+#
 #   This method must be overriden in case your module needs no
 #   standard-behaviour when creating model instances. In that case the method
 #   modelClasses is ignored.
-#   
+#
 #   In most cases you will not need to override it
 #
 # Returns:
 #
 #	array ref - containing instances of the models
-sub models 
+sub models
 {
   my ($self) = @_;
   return $self->providedInstances(TYPE);
@@ -105,7 +105,7 @@ sub newModelInstance
 #   add a instance of a provided model class which can have multiple
 #   instances.  If the class can't have multiple instances a exeception will be
 #   raised
-#   
+#
 #  Parameters:
 #     path - path to the instance. It must contain the index to identifiy the instance
 #   instance - model instance to add
@@ -120,10 +120,10 @@ sub addModelInstance
 #   remove a instance of a provided model class which can have multiple
 #   instances.  If the class can't have multiple instances a exeception will be
 #   raised
-#   
+#
 #  Parameters:
 #     path - path to the instance. It must contain the index to identifiy the instance
-#   
+#
 sub removeModelInstance
 {
   my ($self, $path, $instance) = @_;
@@ -153,7 +153,7 @@ sub removeAllModelInstances
 #  -  the names of all model classes which does not require additional parameters
 #  -  hash reference for other models with the following fields:
 #         class      - the name of the class
-#         parameters - reference to the list of parameters which we want to 
+#         parameters - reference to the list of parameters which we want to
 #                      pass to the model's constructor
 sub modelClasses
 {
@@ -236,10 +236,22 @@ sub AUTOLOAD
 
       $methodName =~ s/.*:://;
 
-      my $exposedMethods = $self->_exposedMethods();
-      if ( exists $exposedMethods->{$methodName} ) {
-          return $self->_callExposedMethod($exposedMethods->{$methodName}, \@params);
+      if ( UNIVERSAL::can($self, '_exposedMethods') ) {
+          my $exposedMethods = $self->_exposedMethods();
+          if ( exists $exposedMethods->{$methodName} ) {
+              return $self->_callExposedMethod($exposedMethods->{$methodName}, \@params);
+          } else {
+              use Devel::StackTrace;
+              my $trace = new Devel::StackTrace();
+              EBox::debug($trace->as_string());
+
+              throw EBox::Exceptions::Internal("Undefined method $methodName");
+          }
       } else {
+          use Devel::StackTrace;
+          my $trace = new Devel::StackTrace();
+          EBox::debug($trace->as_string());
+
           throw EBox::Exceptions::Internal("Undefined method $methodName");
       }
 
@@ -334,10 +346,10 @@ sub _callExposedMethod
                   $separator = $methodDesc->{'separator'};
               } else {
                   $separator = DEFAULT_SEPARATOR;
-              } 
-              @indexValues = grep { $_ ne '' } 
-                                            split ( $separator, 
-                                                    $paramsRef->[0], 
+              }
+              @indexValues = grep { $_ ne '' }
+                                            split ( $separator,
+                                                    $paramsRef->[0],
                                                     scalar(@indexes) + 1 );
               # Remove the index param if any
               shift ( @{$paramsRef} );
@@ -362,21 +374,48 @@ sub _callExposedMethod
 
 
 
-
+# Method: modelsSaveConfig
+#
+#    Method called when the conifguraiton of a modules is saved
 sub modelsSaveConfig
 {
   my ($self) = @_;
 
-  foreach my $model ( @{ $self->models() } ) {
-    if ($model->can('backupFiles')) {
-      $model->backupFiles();
-    }
+  $self->modelsBackupFiles();
+}
 
-  }
+
+# Method: modelsRevokeConfig
+#
+#    Method called when the conifguraiton of a modules is revoked
+sub modelsRevokeConfig
+{
+  my ($self) = @_;
+
+  $self->modelsRestoreFiles();
 
 }
 
-sub modelsRevokeConfig
+# Method: backupFiles
+#
+#   Make an actual configuration backup of all the files contained in the
+#   models
+sub modelsBackupFiles
+{
+  my ($self) = @_;
+
+  foreach my $model ( @{ $self->models() } ) {
+      if ($model->can('backupFiles')) {
+          $model->backupFiles();
+      }
+  }
+}
+
+# Method: restoreFiles
+#
+#  Restores the actual configuration backup of files in the models , thus
+#  discarding the lasts changes in files
+sub modelsRestoreFiles
 {
   my ($self) = @_;
 
@@ -384,26 +423,34 @@ sub modelsRevokeConfig
     if ($model->can('restoreFiles')) {
       $model->restoreFiles();
     }
+
+
   }
 
 }
 
-
-
 sub _filesArchive
 {
   my ($self, $dir) = @_;
   return "$dir/modelsFiles.tar";
 }
 
+
+# Method: backupFilesInArchive
+#
+#  Backup all the modules' files in a compressed archive in the given dir
+#  This is used to create backups
+#
+#   Parameters:
+#   dir - directory where the archive will be stored
 sub backupFilesInArchive
 {
   my ($self, $dir) = @_;
 
   my @filesToBackup;
   foreach my $model ( @{ $self->models() } ) {
-    if ($model->can('backupFilesPaths')) {
-      push @filesToBackup, @{ $model->backupFilesPaths() };
+    if ($model->can('filesPaths')) {
+      push @filesToBackup, @{ $model->filesPaths() };
     }
   }
 
@@ -423,11 +470,17 @@ sub backupFilesInArchive
   foreach my $file (@filesToBackup) {
     $archiveCmd = "tar -C /  -rf $archive --atime-preserve --absolute-names --preserve --same-owner $file";
     EBox::Sudo::root($archiveCmd);
-    
+
   }
 }
 
-
+# Method: restoreFilesFromArchive
+#
+#  Restore all the module's file from the compressed archive in the given dir
+#  This is used to restore backups
+#
+#   Parameters:
+#   dir - directory where the archive is stored
 sub restoreFilesFromArchive
 {
   my ($self, $dir) = @_;
@@ -440,4 +493,6 @@ sub restoreFilesFromArchive
   EBox::Sudo::root($restoreCmd);
 }
 
+
+
 1;
