@@ -192,7 +192,7 @@ sub configured
 # Method: setConfigured
 #
 #   This method is used to set if the module has been configured.
-#   Configuration is done one time per service package version.
+#   Configuration is done once per service package version.
 #
 #   If it's set to true it means that the user has accepted
 #   to carry out the actions and file modifications that enabling a
@@ -351,12 +351,18 @@ sub addModuleStatus
     my $running = $self->isRunning();
     my $name = $self->name();
     my $modPrintName = ucfirst($self->printableName());
+    my $nobutton;
+    if ($self->_supportActions()) {
+        $nobutton = 0;
+    } else {
+        $nobutton = 1;
+    }
     $section->add(new EBox::Dashboard::ModuleStatus(
         module        => $name,
         printableName => $modPrintName,
         enabled       => $enabled,
         running       => $running,
-        nobutton      => not $self->_supportActions()
+        nobutton      => $nobutton,
        ));
 }
 
@@ -364,7 +370,7 @@ sub addModuleStatus
 #
 #   Used to enable a service
 #
-# Paramters:
+# Parameters:
 #
 #   boolean - true to enable, false to disable
 #
@@ -725,4 +731,34 @@ sub certificates
     return [];
 }
 
+# Method: disableApparmorProfile
+#
+#   This method is used to disable a given
+#   apparmor profile.
+#
+#   It does nothing if apparmor or the profile
+#   are not installed.
+#
+# Parameters:
+#
+#   string - apparmor profile
+sub disableApparmorProfile
+{
+    my ($self, $profile) = @_;
+
+    if ( -f '/etc/init.d/apparmor' ) {
+        my $profPath = "/etc/apparmor.d/$profile";
+        my $disPath = "/etc/apparmor.d/disable/$profile";
+        if (-f $profPath and not -f $disPath) {
+            unless ( -d '/etc/apparmor.d/disable' ) {
+                EBox::Sudo::root('mkdir /etc/apparmor.d/disable');
+            }
+            my $cmd = "ln -s $profPath $disPath";
+            EBox::Sudo::root($cmd);
+            EBox::Sudo::root('invoke-rc.d apparmor restart');
+        }
+    }
+
+}
+
 1;
