@@ -1,3 +1,4 @@
+# Copyright (C) 2009 eBox Technologies S.L.
 # Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -22,6 +23,8 @@ use base qw(EBox::GConfModule EBox::Report::DiskUsageProvider);
 
 use Sys::Hostname;
 use Sys::CpuLoad;
+use File::Slurp qw(read_file);
+use Filesys::Df;
 
 use EBox::Config;
 use EBox::Gettext;
@@ -30,19 +33,26 @@ use EBox::Dashboard::Widget;
 use EBox::Dashboard::Section;
 use EBox::Dashboard::List;
 use EBox::Dashboard::Value;
+use EBox::Dashboard::HTML;
 use EBox::Menu::Item;
 use EBox::Menu::Folder;
+use EBox::Report::DiskUsage;
 use EBox::Report::RAID;
+use EBox::Util::Version;
 
+use constant LATEST_VERSION => '/var/lib/ebox/latestversion';
 
 sub _create
 {
-	my $class = shift;
-	my $self = $class->SUPER::_create(name => 'sysinfo',
-                                          printableName => __('System Information'),
-                                          @_);
-	bless($self, $class);
-	return $self;
+    my $class = shift;
+    my $self = $class->SUPER::_create(name => 'sysinfo',
+                                      domain => 'ebox',
+                                      printableName => __n('System Information'),
+                                      @_);
+    $self->{version} = "1.5";
+
+    bless($self, $class);
+    return $self;
 }
 
 
@@ -74,11 +84,22 @@ sub generalWidget
     my $time_command = "LC_TIME=" . EBox::locale() . " /bin/date";
     my $time = `$time_command`;
 
+    my $version = $self->{version};
+    my $lastVersion;
+    open (my $fh, LATEST_VERSION);
+    read ($fh, $lastVersion, 16);
+    chomp($lastVersion);
+    close ($fh);
+    if (EBox::Util::Version::compare($lastVersion,$version) == 1) {
+        my $url = "http://www.ebox-platform.com/ebox-update";
+        my $available = __('available');
+        $version .=
+           " (<a target='_blank' href='$url'>$lastVersion $available</a>)";
+    }
+
     $section->add(new EBox::Dashboard::Value(__("Time"), $time));
     $section->add(new EBox::Dashboard::Value(__("Hostname"), hostname));
-    $section->add(new EBox::Dashboard::Value(
-    __("eBox version"),
-    EBox::Config::version));
+    $section->add(new EBox::Dashboard::Value(__("Core version"), $version));
     $section->add(new EBox::Dashboard::Value(
         __("System load"), join(', ', Sys::CpuLoad::load)));
 }
@@ -102,6 +123,16 @@ sub processesWidget
     $section->add(new EBox::Dashboard::List(undef, $titles, $ids, $rows));
 }
 
+sub linksWidget
+{
+    my ($self, $widget) = @_;
+    my $section = new EBox::Dashboard::Section('links');
+    $widget->add($section);
+
+    my $html = read_file(EBox::Config::share() . 'ebox/www/links-widget.html');
+    $section->add(new EBox::Dashboard::HTML($html));
+}
+
 #
 # Method: widgets
 #
@@ -113,7 +144,8 @@ sub processesWidget
 #
 sub widgets
 {
-    return {
+
+    my $widgets = {
         'modules' => {
             'title' => __("Module Status"),
             'widget' => \&modulesWidget,
@@ -129,6 +161,16 @@ sub widgets
             'widget' => \&processesWidget
         },
     };
+
+    unless (EBox::Config::configkey('disable_links_widget') eq 'yes') {
+        $widgets->{'links'} = {
+            'title' => __("Resources & Services"),
+            'widget' => \&linksWidget,
+            'default' => 1
+        };
+    }
+
+    return $widgets;
 }
 
 sub addKnownWidget()
@@ -179,58 +221,111 @@ sub toggledElements()
 #
 # Method: menu
 #
-#   	Overriden method that returns the core menu entries:
+#   Overriden method that returns the core menu entries:
 #
-#	- Summary
-#	- Save/Cancel
-#	- Logout
-#	- EBox/General
-#	- EBox/Backup
-#	- EBox/Halt
-#	- EBox/Bug
+#   - Summary
+#   - Save/Cancel
+#   - Logout
+#   - EBox/General
+#   - EBox/Backup
+#   - EBox/Halt
+#   - EBox/Bug
 sub menu
 {
-	my ($self, $root) = @_;
+    my ($self, $root) = @_;
 
-	$root->add(new EBox::Menu::Item('url' => 'Dashboard/Index',
-					'text' => __('Dashboard'),
-					'separator' => __('Core'),
-					'order' => 10));
+    $root->add(new EBox::Menu::Item('url' => 'Dashboard/Index',
+                    'text' => __('Dashboard'),
+                    'separator' => 'Core',
+                    'order' => 10));
 
-	$root->add(new EBox::Menu::Item('url' => 'ServiceModule/StatusView',
-					'text' => __('Module Status'),
-					'separator' => __('Core'),
-					'order' => 20));
+    $root->add(new EBox::Menu::Item('url' => 'ServiceModule/StatusView',
+                    'text' => __('Module Status'),
+                    'separator' => 'Core',
+                    'order' => 20));
 
 
-	my $folder = new EBox::Menu::Folder('name' => 'EBox',
-					    'text' => __('System'),
-					    'order' => 30);
+    my $folder = new EBox::Menu::Folder('name' => 'EBox',
+                        'text' => __('System'),
+                        'order' => 30);
 
-	$folder->add(new EBox::Menu::Item('url' => 'EBox/General',
-					  'text' => __('General')));
+    $folder->add(new EBox::Menu::Item('url' => 'EBox/General',
+                      'text' => __('General')));
 
-	$folder->add(new EBox::Menu::Item('url' => 'Report/DiskUsage',
-					  'text' => __('Disk Usage')));
+    $folder->add(new EBox::Menu::Item('url' => 'Report/DiskUsage',
+                      'text' => __('Disk Usage')));
 
-	$folder->add(new EBox::Menu::Item(
-			 'url' => 'Report/RAID',
+    $folder->add(new EBox::Menu::Item(
+             'url' => 'Report/RAID',
              'text' => __('RAID'))
-		    );
+            );
 
 
-	$folder->add(new EBox::Menu::Item('url' => 'EBox/Backup',
-					  'text' => __('Backup')));
+    $folder->add(new EBox::Menu::Item('url' => 'EBox/Backup',
+                      'text' => __('Backup')));
 
-	$folder->add(new EBox::Menu::Item('url' => 'EBox/Halt',
-					  'text' => __('Halt/Reboot')));
+    $folder->add(new EBox::Menu::Item('url' => 'EBox/Halt',
+                      'text' => __('Halt/Reboot')));
 
-#	$folder->add(new EBox::Menu::Item('url' => 'EBox/Bug',
-#					  'text' => __('Bug report')));
+#   $folder->add(new EBox::Menu::Item('url' => 'EBox/Bug',
+#                     'text' => __('Bug report')));
 
 
 
-	$root->add($folder);
+    $root->add($folder);
+}
+
+sub logReportInfo
+{
+    my ($self) = @_;
+
+    my @data;
+
+    my $fileSysS = EBox::Report::DiskUsage::partitionsFileSystems();
+    foreach my $fileSys (keys %{$fileSysS}) {
+        my $entry = {};
+        $entry->{'table'} = 'sysinfo_disk_usage';
+        $entry->{'values'} = {};
+        my $mount = $fileSysS->{$fileSys}->{mountPoint};
+        $entry->{'values'}->{'mountpoint'} = $mount;
+        my $info = df($mount);
+        $entry->{'values'}->{'used'} = $info->{'used'};
+        $entry->{'values'}->{'free'} = $info->{'bavail'};
+        push(@data, $entry)
+    }
+    return \@data;
+}
+
+sub consolidateReportInfoQueries
+{
+    return [
+        {
+            'target_table' => 'sysinfo_disk_usage_report',
+            'query' => {
+                'select' => 'mountpoint, used, free',
+                'from' => 'sysinfo_disk_usage',
+                'key' => 'mountpoint'
+            }
+        }
+    ];
+}
+
+# Method: report
+#
+# Overrides:
+#   <EBox::Module::Base::report>
+sub report
+{
+    my ($self, $beg, $end, $options) = @_;
+
+    my $report = {};
+
+    $report->{'disk_usage'} = $self->runMonthlyQuery($beg, $end, {
+        'select' => 'mountpoint, used, free',
+        'from' => 'sysinfo_disk_usage_report',
+    }, { 'key' => 'mountpoint' });
+
+    return $report;
 }
 
 1;
