@@ -173,7 +173,7 @@ sub cmp
     return undef unless ( $self->type() eq $compareType->type() );
 
     my @selfTypes = @{$self->types()};
-    my @comparedTypes = @{$self->types()};
+    my @comparedTypes = @{$compareType->types()};
 
     return undef unless ( scalar(@selfTypes) == scalar(@comparedTypes) );
     my $returnValue = undef;
@@ -348,6 +348,7 @@ sub _callTypeMethod # (methodName, args)
     my ($self, $methodName, @args) = @_;
 
     foreach my $simpleType ( @{$self->types()} ) {
+        $simpleType->setRow($self->row());
         $simpleType->$methodName(@args);
     }
 
