@@ -100,8 +100,9 @@ sub printableValue
 {
     my ($self) = @_;
 
-    if ( defined ($self->{filePath}) ) {
-        return basename($self->{filePath});
+    my $path = $self->path();
+    if ( defined ($path) ) {
+        return basename($path);
     } else {
         return '';
     }
@@ -112,7 +113,7 @@ sub printableValue
 #
 # Overrides:
 #
-#       <EBox::Types::Abstract::compareToHash>
+#       <EBox::Types::Abstract::isEqualTo>
 #
 sub isEqualTo
 {
@@ -136,7 +137,7 @@ sub isEqualTo
             # diff command failed, we assume that they ar different (cannot find
             # a reliable docuentation of diff's return values)
             $equal = 0;
-            
+
         };
 
         return $equal;
@@ -189,7 +190,7 @@ sub path
 # Method: user
 #
 # Returns:
-#         - the user which will own the file  
+#         - the user which will own the file
 sub user
 {
     my ($self) = @_;
@@ -204,7 +205,7 @@ sub user
 # Method: group
 #
 # Returns:
-#         - the group which will own the file  
+#         - the group which will own the file
 sub group
 {
     my ($self) = @_;
@@ -228,7 +229,12 @@ sub group
 #
 sub exist
 {
-    my ($self) = @_;
+    my ($self, $path) = @_;
+    defined $path or
+        $path = $self->path();
+    $path or
+        return undef;
+
 
     if ( $self->path() ) {
         return EBox::Sudo::fileTest('-f', $self->path);
@@ -237,13 +243,13 @@ sub exist
     }
 }
 
-# Method: toRemove 
+# Method: toRemove
 #
 #    Check if the file has been marked to be removed
 #
 # Returns:
 #
-#    boolean -  
+#    boolean -
 #
 sub toRemove
 {
@@ -252,6 +258,18 @@ sub toRemove
     return $self->{remove};
 }
 
+
+sub filesPaths
+{
+    my ($self) = @_;
+    if ($self->exist()) {
+        return [ $self->path() ];
+    }
+    else {
+        return []
+    }
+}
+
 # Method: allowDownload
 #
 #     Check if it is possible to allow download or not from the viewer
@@ -316,7 +334,7 @@ sub linkToDownload
     $link .= "/$modelName" if ($modelName);
     $link .= "/$index" if ($index);
     $link .= '&dir=' . $self->model()->directory();
-    $link .= '&id=' . $self->row()->id(); 
+    $link .= '&id=' . $self->row()->id();
     $link .= '&field='  . $self->fieldName();
 
     return $link;
@@ -355,6 +373,107 @@ sub userPath
 
     return $self->{userPath};
 
+}
+
+#  Method: backupPath
+#
+#   return the path to the actual configuration backup
+#
+# Parameters:
+#   path - path of the file which owns the backup, if it is not
+#       provided the path() method will be used
+sub backupPath
+{
+    my ($self, $path) = @_;
+    defined $path or
+      $path = $self->path();
+    $path or
+      return undef;
+
+    my $backupPath = $path . '.bak';
+    return $backupPath;
+}
+
+#  Method: noPreviousFilePath
+#
+#   return the path to the file to signals to the actual configuration backup
+#   that there wasn't any file before
+#
+# Parameters:
+#   path - path of the file which owns the backup, if it is not
+#       provided the path() method will be used
+sub noPreviousFilePath
+{
+    my ($self, $path) = @_;
+    defined $path or
+      $path = $self->path();
+    $path or
+      return undef;
+
+    my $backupPath = $path . '.noprevious.bak';
+    return $backupPath;
+}
+
+# Method: backupFiles
+#
+#   Make an actual configuration backup of the file.. This backup will used to
+#   discard changes when revoking the configuration
+#
+# Parameters:
+#   path - path of the file which owns the backup, if it is not
+#       provided the path() method will be used
+sub backupFiles
+{
+    my ($self, $path) = @_;
+    defined $path or
+      $path = $self->path();
+    $path or return;
+
+
+    my $backupPath = $self->backupPath($path);
+    my $noPreviousFilePath = $self->noPreviousFilePath($path);
+
+    if ($self->exist($path)) {
+
+        $backupPath or return;
+
+        EBox::Sudo::root("cp -p $path $backupPath");
+        EBox::Sudo::root("rm -f $noPreviousFilePath");
+    } else {
+        EBox::Sudo::root("touch $noPreviousFilePath");
+        EBox::Sudo::root("rm -f $backupPath");
+    }
+
+}
+
+# Method: restoreFiles
+#
+#  Restores the actual configuration backup of the file, thus discarding last
+#  changes
+#
+# Parameters:
+#   path - path of the file which owns the backup, if it is not
+#       provided the path() method will be used
+sub restoreFiles
+{
+    my ($self, $path) = @_;
+    defined $path or
+      $path = $self->path();
+    $path or return;
+
+    my $backupPath = $self->backupPath($path);
+    if ( EBox::Sudo::fileTest('-f', $backupPath) ) {
+        EBox::Sudo::root("cp -p $backupPath $path");
+        return;
+    }
+
+    my $noPreviousFilePath = $self->noPreviousFilePath($path);
+    if ( EBox::Sudo::fileTest('-f', $noPreviousFilePath) ) {
+        EBox::Sudo::root("rm -f $path");
+    }
+
+
+
 }
 
 # Group: Protected methods
@@ -394,8 +513,10 @@ sub _storeInGConf
 
     my $keyField = "$key/" . $self->fieldName() . '_path';
 
+
     if ($self->path() and $self->userPath()) {
         $gconfmod->set_string($keyField, $self->path());
+
         # Do actually move
         $self->_moveToPath();
 
@@ -411,47 +532,6 @@ sub _storeInGConf
     }
 }
 
-
-
-sub _moveToPath
-{
-    my ($self) = @_;
-
-    my $path   = $self->path();
-
-    my $tmpPath = $self->tmpPath();
-    if (not -f $tmpPath) {
-        throw EBox::Exceptions::Internal("No file found at $tmpPath for moving to $path");
-    }
-
-    my $user = $self->user();
-    my $group = $self->group();
-
-    if (($user eq  'root') or ($group eq 'root')) {
-        EBox::Sudo::root("mv $tmpPath $path");
-        try {
-            EBox::Sudo::root("chown $user.$group $path");
-        }
-        otherwise {
-            my $ex = shift;
-            EBox::Sudo::root("rm -f $path");
-            $ex->throw();
-        };
-    }
-    elsif (($user eq 'ebox') and ($group eq 'ebox')) {
-        File::Copy::move($tmpPath, $self->path()) or
-              throw EBox::Exceptions::Internal("Cannot move from $tmpPath "
-                                               . ' to ' . $self->path());
-    }
-    else {
-        throw EBox::Exceptions::NotImplemented(
-                 "user and group combination not supported"
-                                              );
-    }
-
-}
-
-
 # Method: _restoreFromHash
 #
 # Overrides:
@@ -504,73 +584,84 @@ sub _paramIsSet
 
 }
 
-
-
-sub backupPath
+# Method: _setValue
+#
+#    Set the value for the file.
+#
+#    Two choices are available:
+#
+#         - give a path where the file will be stored (given a
+#         non-empty string). The file must be set in
+#         <EBox::Config::tmp> and the name must match "$fieldName" + '_path'
+#
+#         - remove the current value passing (given an empty string or undef)
+#
+# Overrides:
+#
+#    <EBox::Types::Abstract::_setValue>
+#
+# Parameters:
+#
+#    value - String the path to store in file type or an empty string
+#    to remove it
+#
+sub _setValue #(value)
 {
-  my ($self) = @_;
-  my $path = $self->path();
-  $path or return undef;
+    my ($self, $value) = @_;
 
-  my $backupPath = $path . '.bak';
-  return $backupPath;
-}
+    my $params = {};
+    if ( $value ) {
+        $params->{$self->fieldName() . '_path'} = $value;
+    } else {
+        $params->{$self->fieldName() . '_remove'} = $value;
+    }
 
-sub noPreviousFilePath
-{
-  my ($self) = @_;
-  my $path = $self->path();
-  $path or return undef;
-
-  my $backupPath = $path . '.noprevious.bak';
-  return $backupPath;
-}
-
-
-#  in backup and restore method is assummed that all files are owned by ebox
-sub backup
-{
-  my ($self) = @_;
-  my $path        = $self->path();
-  $path or return;
-
-  my $backupPath = $self->backupPath();
-  my $noPreviousFilePath = $self->noPreviousFilePath();
-
-  if ($self->exist()) {
-
-    $backupPath or return;
-
-    EBox::Sudo::root("cp -p $path $backupPath");
-    EBox::Sudo::root("rm -f $noPreviousFilePath");
-  }
-  else {
-    EBox::Sudo::root("touch $noPreviousFilePath");
-    EBox::Sudo::root("rm -f $backupPath");
-  }
+    $self->setMemValue($params);
 
 }
 
+# Group: Private methods
 
-sub restore
+sub _moveToPath
 {
-  my ($self) = @_;
+    my ($self) = @_;
 
-  my $path = $self->path();
-  $path or return;
+#     # assure we have backuped the current config
+#     my $gconfmod = $self->model()->{gconfmodule};
+#     $gconfmod->_backup();
 
-  my $backupPath = $self->backupPath();
-  if ( EBox::Sudo::fileTest('-f', $backupPath) ) {
-      EBox::Sudo::root("cp -p $backupPath $path");
-      return;
-  }
-  
-  my $noPreviousFilePath = $self->noPreviousFilePath();
-  if ( EBox::Sudo::fileTest('-f', $noPreviousFilePath) ) {
-      EBox::Sudo::root("rm -f $path");
-  }
-  
 
+    my $path   = $self->path();
+
+    my $tmpPath = $self->tmpPath();
+    if (not -f $tmpPath) {
+        throw EBox::Exceptions::Internal("No file found at $tmpPath for moving to $path");
+    }
+
+    my $user = $self->user();
+    my $group = $self->group();
+
+    if (($user eq  'root') or ($group eq 'root')) {
+        EBox::Sudo::root("mv $tmpPath $path");
+        try {
+            EBox::Sudo::root("chown $user.$group $path");
+        }
+        otherwise {
+            my $ex = shift;
+            EBox::Sudo::root("rm -f $path");
+            $ex->throw();
+        };
+    }
+    elsif (($user eq 'ebox') and ($group eq 'ebox')) {
+        File::Copy::move($tmpPath, $self->path()) or
+              throw EBox::Exceptions::Internal("Cannot move from $tmpPath "
+                                               . ' to ' . $self->path());
+    }
+    else {
+        throw EBox::Exceptions::NotImplemented(
+                 "user and group combination not supported"
+                                              );
+    }
 
 }
 
